This file is part of PySunsSpec-Reader

PySunSpec-Read is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    PySunSpec-Read is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with PySunSpec-Read.  If not, see <https://www.gnu.org/licenses/>.    

TODO - this is a work in-progress, I usually end up overengineering my solar readers for some reason.
At least this one is a bit simpler than the last one...